==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/fr.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "fr", 
    "plural-forms": "nplurals=2; plural=(n > 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "%(num)d élément", 
    "%(num)d éléments"
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "%(num)d traduction manquante", 
    "%(num)d traductions manquantes"
  ], 
  "Add Filter": [
    null, 
    "Ajouter un filtre"
  ], 
  "An Error Occurred": [
    null, 
    "Erreur"
  ], 
  "An error occured during AJAX request. Could not load view.": [
    null, 
    "Une erreur est survenue durant une requête AJAX. La vue n'a pas pu être chargée."
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Etes-vous sûr de vouloir exécuter cette commande ?"
  ], 
  "Cancel": [
    null, 
    "Annuler"
  ], 
  "Confirm": [
    null, 
    "Confirmation"
  ], 
  "Could not load view": [
    null, 
    "Impossible de charger la vue"
  ], 
  "DataProxy returned an error": [
    null, 
    "DataProxy a retourné une erreur"
  ], 
  "DataStore returned an error": [
    null, 
    "Le Magasin de Données a retourné une erreur"
  ], 
  "Edit": [
    null, 
    "Éditer"
  ], 
  "Failed to load data API information": [
    null, 
    "Le chargement de l'information de l'API de données a échoué"
  ], 
  "File": [
    null, 
    "Fichier"
  ], 
  "Filters": [
    null, 
    "Filtres"
  ], 
  "Follow": [
    null, 
    "S'abonner"
  ], 
  "Graph": [
    null, 
    "Graphe"
  ], 
  "Grid": [
    null, 
    "Grille"
  ], 
  "Hide": [
    null, 
    "Cacher"
  ], 
  "Image": [
    null, 
    "Image"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "Saisie trop courte, au moins un caractère est nécessaire", 
    "Saisie trop courte, au moins %(num)d caractères  sont nécessaires"
  ], 
  "Link": [
    null, 
    "Lien"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Lien vers une URL sur internet (vous pouvez aussi donner un lien vers une API)"
  ], 
  "Loading...": [
    null, 
    "Chargement..."
  ], 
  "Map": [
    null, 
    "Carte"
  ], 
  "No matches found": [
    null, 
    "Aucune correspondance trouvée"
  ], 
  "Please Confirm Action": [
    null, 
    "Veuillez confirmer l'action"
  ], 
  "Remove": [
    null, 
    "Supprimer"
  ], 
  "Reorder resources": [
    null, 
    "Réordonner les ressources"
  ], 
  "Resource uploaded": [
    null, 
    "Ressource  téléchargée"
  ], 
  "Save order": [
    null, 
    "Enregistrer l'ordre"
  ], 
  "Saving...": [
    null, 
    "Sauvegarde en cours..."
  ], 
  "Select a field": [
    null, 
    "Sélectionnez un champ"
  ], 
  "Show more": [
    null, 
    "Montrer plus"
  ], 
  "Start typing…": [
    null, 
    "Commencez la saisie ..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Des modifications de ce formulaire n'ont pas été enregistrées"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Il n'y a pas de données API à télécharger pour cette ressource"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Échec de l'authentification du transfert"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Impossible d'accéder aux données du fichier déposé"
  ], 
  "Unable to upload file": [
    null, 
    "Échec du transfert de fichier "
  ], 
  "Unfollow": [
    null, 
    "Se désabonner"
  ], 
  "Upload": [
    null, 
    "Envoi"
  ], 
  "Upload a file": [
    null, 
    "Envoyer un fichier depuis votre ordinateur"
  ], 
  "Upload a file on your computer": [
    null, 
    "Télécharger un fichier sur votre ordinateur"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "Vous êtes en train de transférer un fichier. Êtes-vous sûr de vouloir naviguer ailleurs et interrompre ce transfert ?"
  ], 
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null, 
    "Vous pouvez trier les resources par glisser-déposer en utilisant l'icône en forme de flèches. Quand vous avez terminé, cliquez sur le bouton « Enregistrer l'ordre »."
  ], 
  "bar": [
    "bars", 
    "tata", 
    "tatas"
  ], 
  "error loading view": [
    null, 
    "erreur lors du chargement de la vue"
  ], 
  "foo": [
    null, 
    "toto"
  ], 
  "hello %(name)s!": [
    null, 
    "bonjour %(name)s !"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "no %(attr)s translation", 
    "no %(attr)s translations"
  ], 
  "no translation": [
    "no translations", 
    "pas de traduction", 
    "pas de traduction"
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/fr.js <==
{
  "": {
    "domain": "ckan",
    "lang": "fr",
    "plural-forms": "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;"
  },
  "Add Filter": [
    null,
    "Ajouter un filtre"
  ],
  "An Error Occurred": [
    null,
    "Erreur"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "Une erreur est survenue durant une requête AJAX. La vue n'a pas pu être chargée."
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Etes-vous sûr de vouloir exécuter cette commande ?"
  ],
  "Cancel": [
    null,
    "Annuler"
  ],
  "Confirm": [
    null,
    "Confirmation"
  ],
  "Could not load view": [
    null,
    "Impossible de charger la vue"
  ],
  "DataProxy returned an error": [
    null,
    "DataProxy a retourné une erreur"
  ],
  "DataStore returned an error": [
    null,
    "Le Magasin de Données a retourné une erreur"
  ],
  "Edit": [
    null,
    "Éditer"
  ],
  "Failed to load data API information": [
    null,
    "Le chargement de l'information de l'API de données a échoué"
  ],
  "File": [
    null,
    "Fichier"
  ],
  "Filters": [
    null,
    "Filtres"
  ],
  "Follow": [
    null,
    "S'abonner"
  ],
  "Graph": [
    null,
    "Graphe"
  ],
  "Grid": [
    null,
    "Grille"
  ],
  "Hide": [
    null,
    "Cacher"
  ],
  "Image": [
    null,
    "Image"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "Saisie trop courte, au moins un caractère est nécessaire",
    "Saisie trop courte, au moins %(num)d caractères  sont nécessaires",
    "Saisie trop courte, au moins %(num)d caractères  sont nécessaires"
  ],
  "Link": [
    null,
    "Lien"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Lien vers une URL sur internet (vous pouvez aussi donner un lien vers une API)"
  ],
  "Loading...": [
    null,
    "Chargement..."
  ],
  "Map": [
    null,
    "Carte"
  ],
  "No matches found": [
    null,
    "Aucune correspondance trouvée"
  ],
  "Please Confirm Action": [
    null,
    "Veuillez confirmer l'action"
  ],
  "Remove": [
    null,
    "Supprimer"
  ],
  "Reorder resources": [
    null,
    "Réordonner les ressources"
  ],
  "Resource uploaded": [
    null,
    "Ressource  téléchargée"
  ],
  "Save order": [
    null,
    "Enregistrer l'ordre"
  ],
  "Saving...": [
    null,
    "Sauvegarde en cours..."
  ],
  "Select a field": [
    null,
    "Sélectionnez un champ"
  ],
  "Show more": [
    null,
    "Montrer plus"
  ],
  "Start typing…": [
    null,
    "Commencez la saisie ..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Des modifications de ce formulaire n'ont pas été enregistrées"
  ],
  "There is no API data to load for this resource": [
    null,
    "Il n'y a pas de données API à télécharger pour cette ressource"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Échec de l'authentification du transfert"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Impossible d'accéder aux données du fichier déposé"
  ],
  "Unable to upload file": [
    null,
    "Échec du transfert de fichier "
  ],
  "Unfollow": [
    null,
    "Se désabonner"
  ],
  "Upload": [
    null,
    "Envoi"
  ],
  "Upload a file": [
    null,
    "Envoyer un fichier depuis votre ordinateur"
  ],
  "Upload a file on your computer": [
    null,
    "Télécharger un fichier sur votre ordinateur"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Vous êtes en train de transférer un fichier. Êtes-vous sûr de vouloir naviguer ailleurs et interrompre ce transfert ?"
  ],
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null,
    "Vous pouvez trier les resources par glisser-déposer en utilisant l'icône en forme de flèches. Quand vous avez terminé, cliquez sur le bouton « Enregistrer l'ordre »."
  ],
  "error loading view": [
    null,
    "erreur lors du chargement de la vue"
  ]
}
